==> pochy-0.1.2b-src.tar.gz: pochy-0.1.2b-src/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by pochy.rc
//
#define ID_NEWACCOUNT                   3
#define ID_GENKEY                       3
#define ID_SAVE_USER                    4
#define ID_REMOVE_USER                  4
#define ID_DELKEY                       4
#define IDD_ABOUTBOX                    100
#define IDD_FORMVIEW                    101
#define IDR_MAINFRAME                   128
#define IDR_MOOTYPE                     129
#define IDR_DRAFTFRAME                  129
#define IDB_TREEVIEW                    132
#define IDI_ICON1                       133
#define IDI_ICON2                       134
#define IDI_ICON3                       135
#define IDR_MULTIPART                   136
#define IDR_MULTIPART_POPUP             136
#define IDI_ICON4                       137
#define IDD_DIALOG1                     138
#define IDD_PROGRESS                    138
#define IDD_DIALOG2                     139
#define IDD_DIALOG3                     140
#define IDD_RETRIEVE                    140
#define IDB_BITMAP2                     142
#define IDD_DIALOG4                     143
#define IDD_PASSWORD                    143
#define IDD_DIALOG5                     144
#define IDD_GPG_ENCODE_SELKEY           144
#define IDD_DIALOG6                     145
#define IDD_SETTING_ACCOUNT             145
#define IDD_DIALOG7                     148
#define IDD_DIALOG8                     149
#define IDR_EMPTY_HTML                  151
#define IDR_MULTIPART_DRAFT             152
#define IDR_MULTIPART_DRAFT_POPUP       152
#define IDD_DIALOG9                     153
#define IDD_DRAFT_CONFIRM               153
#define IDR_TEXTVIEW_POPUP              154
#define IDD_DIALOG10                    155
#define IDR_EDITVIEW_POPUP              156
#define IDR_TEST                        158
#define IDR_TOOLBAR1                    160
#define IDB_BITMAP3                     165
#define IDR_TOOLBAR2                    166
#define IDR_TOOLBAR3                    168
#define IDR_MAINFRAME_POPUP_REPLY       170
#define IDR_MAINFRAME_POPUP_TRANSFER    171
#define IDD_DIALOG11                    172
#define IDD_ADDR2_TAB_TO                173
#define IDD_ADDR2_TAB1                  173
#define IDD_ADDR2_TAB_PG1               173
#define IDC_ADDR2_LIST2                 173
#define IDR_MAINFRAME_POPUP_GPG         174
#define IDD_GPG_GENERAL                 175
#define IDR_TOOLBAR4                    178
#define IDR_DRAFTFRAME_POPUP_GPG        180
#define IDR_FOLDERVIEW_POPUP            181
#define IDD_ADDRESSVIEW                 182
#define IDD_FILTER                      183
#define IDD_ACCOUNTVIEW                 185
#define IDD_DRAFT_ADDRESSBOOK           190
#define IDD_MAIN_ADDRESSBOOK            191
#define IDD_SETTING_GENERAL             192
#define IDR_MAINFRAME_POPUP_SETTING     193
#define IDD_MAIN_ADDRESSBOOK_ADD        194
#define IDR_MAINFRAME_POPUP_INFO        195
#define IDD_DRAFT_ADDRESSBOOK_ADD       196
#define IDD_MAIN_ADDRESSBOOK_EDIT       197
#define IDD_SETTING_GENERAL_APPEARANCE  198
#define IDD_SETTING_GENERAL_OTHER       199
#define IDD_DIALOG12                    200
#define IDD_DRAFT_SEND_STATUS           201
#define IDR_SUMMARYVIEW_POPUP           203
#define IDC_EDIT1                       1000
#define IDC_EDIT2                       1001
#define IDC_PROGRESS1                   1002
#define IDC_EDIT3                       1002
#define IDC_BUTTON1                     1003
#define IDC_EDIT4                       1003
#define IDC_GPG_EXPORT                  1003
#define IDC_LIST1                       1004
#define IDC_EDIT5                       1004
#define IDC_BUTTON2                     1005
#define IDC_ADDR2_LIST1                 1005
#define IDC_FROM                        1005
#define IDC_EDIT6                       1006
#define IDC_BUTTON3                     1006
#define IDC_ADDR2_DEL2                  1006
#define IDC_FILTER_REPLACE              1006
#define IDC_SETTING_ADDRESS             1006
#define IDC_MAINFRAME_ADDRESSBOOK_DEL   1006
#define IDC_COMBO1                      1007
#define IDC_BUTTON4                     1007
#define IDC_PASS                        1007
#define IDC_BUTTON_TO                   1007
#define IDC_SETTING_GENERAL_DEFACCOUNT  1007
#define IDC_EDIT7                       1008
#define IDC_LIST2                       1008
#define IDC_BUTTON5                     1008
#define IDC_FILTER_MOVE_TO              1008
#define IDC_SETTING_USERID              1008
#define IDC_DRAFT_ADDRESSBOOK_DST_LIST  1008
#define IDC_BUTTON_CC                   1008
#define IDC_BUTTON6                     1009
#define IDC_FILTER_FIELD                1009
#define IDC_SETTING_BOXNAME             1009
#define IDC_BUTTON_BCC                  1009
#define IDC_SETTING_SIG                 1011
#define IDC_SETTING_CHECK_DELMAIL       1014
#define IDC_COMBOBOXEX1                 1016
#define IDC_SETTING_CHECK_POP_BEFORE_SMTP 1017
#define IDC_DRAFT_ADDRESSBOOK_TAB       1019
#define IDC_SETTING_GENERAL_TAB         1019
#define IDC_ADDR2_ADD                   1020
#define IDC_GPG_DEL                     1028
#define IDC_GPG_KEY_TYPE                1029
#define IDC_GPG_DSA                     1030
#define IDC_GPG_ELG                     1031
#define IDC_GPG_KEY_LENGTH              1032
#define IDC_GPG_1024                    1033
#define IDC_GPG_2048                    1034
#define IDC_GPG_ADD                     1035
#define IDC_GPG_ADD_KEY                 1035
#define IDC_GPG_DATE2                   1037
#define IDC_GPG_REAL_NAME               1039
#define IDC_GPG_COMMENT                 1040
#define IDC_MAIL_ADDRESS                1041
#define IDC_GPG_DATE1                   1043
#define IDC_GPG_CREATE                  1044
#define IDC_GPG_LIST1                   1045
#define IDC_GPG_KEY                     1046
#define IDC_GPG_CLEAR1                  1047
#define IDC_GPG_CLEAR2                  1048
#define IDC_GPG_STATUS                  1049
#define IDC_GPG_OPEN_KEY                1050
#define IDC_TO                          1050
#define IDC_CC                          1051
#define IDC_BCC                         1052
#define IDC_SUBJECT                     1053
#define IDC_REPLY_TO                    1054
#define IDC_FILTER_PHRASE               1055
#define IDC_FILTER_CONDITION            1056
#define IDC_FILTER_ADD                  1057
#define IDC_FILTER_DEL                  1058
#define IDC_COMBO_ACCOUNT               1059
#define IDC_STATIC_FROM                 1060
#define IDC_STATIC_SUBJECT              1061
#define IDC_STATIC_REPLY_TO             1062
#define IDC_SETTING_PASS                1063
#define IDC_SETTING_POP_IP              1064
#define IDC_SETTING_SMTP_IP             1065
#define IDC_SETTING_POP_PORT            1066
#define IDC_SETTING_SMTP_PORT           1067
#define IDC_DRAFT_ADDRESSBOOK_ORG_LIST  1068
#define IDC_DRAFT_ADDRESSBOOK_ADD       1069
#define IDC_DRAFT_ADDRESSBOOK_DEL       1070
#define IDC_DRAFT_ADDRESSBOOK_EDIT      1071
#define IDC_MAINFRAME_ADDRESS_LIST      1071
#define IDC_MAINFRAME_ADDRESSBOOK_ADD   1072
#define IDC_DRAFT_ADDRESSBOOK_ADD2      1072
#define IDC_MAINFRAME_ADDRESSBOOK_EDIT  1073
#define IDC_DRAFT_ADDRESSBOOK_ADD_NAME  1074
#define IDC_MAIN_ADDRESSBOOK_ADD_NAME   1074
#define IDC_DRAFT_ADDRESSBOOK_ADD_ADDRESS 1075
#define IDC_MAIN_ADDRESSBOOK_ADD_ADDRESS 1075
#define IDC_DRAFT_ADDRESSBOOK_ADD_OTHERS 1076
#define IDC_MAIN_ADDRESSBOOK_ADD_OTHERS 1076
#define IDC_MAIN_ADDRESSBOOK_EDIT_NAME  1078
#define IDC_MAIN_ADDRESSBOOK_EDIT_ADDRESS 1079
#define IDC_MAIN_ADDRESSBOOK_EDIT_OTHER 1080
#define IDC_SETTING_GENERAL_FOLDERVIEW_BG_COLOR 1081
#define IDC_SETTING_GENERAL_SUMMARYVIEW_BG_COLOR 1082
#define IDC_SETTING_GENERAL_TEXTVIEW_BG_COLOR 1083
#define IDC_SETTING_GENERAL_AUTOFETCH_MINUTES 1083
#define IDC_SETTING_GENERAL_FOLDERVIEW_FONT_COLOR 1084
#define IDC_SETTING_GENERAL_EDITOR_REF  1084
#define IDC_SETTING_GENERAL_SUMMARYVIEW_FONT_COLOR 1085
#define IDC_SETTING_GENERAL_EDITOR_PATH 1085
#define IDC_SETTING_GENERAL_TEXTVIEW_FONT_COLOR 1086
#define IDC_DRAFT_SEND_PROGRESS         1086
#define IDC_SETTING_GENERAL_TEXTVIEW_FONT_TYPE 1087
#define IDC_DRAFT_SEND_STATUS           1087
#define IDC_SETTING_GENERAL_TEXTVIEW_HEADER_COLOR 1088
#define IDC_DRAFT_ADDRESSBOOK_CHECK_ADDRESS 1088
#define IDC_SETTING_GENERAL_EDITVIEW_BG_COLOR 1089
#define IDC_SETTING_CHECK_APOP          1089
#define IDC_SETTING_GENERAL_EDITVIEW_FONT_COLOR 1090
#define IDC_ABOUTBOX_VERSION            1090
#define IDC_SETTING_GENERAL_EDITVIEW_FONT_TYPE 1091
#define IDC_APPABOUT_COPY               1091
#define ID_DRAFT                        32771
#define ID_FETCH_MAIL                   32773
#define ID_SEND_MAIL                    32774
#define ID_TRANSFER                     32779
#define ID_ADD_FILE                     32780
#define ID_SAVETO_FILE                  32782
#define ID_MULTIPART_SAVE2FILE          32782
#define ID_MULTIPART_HEADER             32783
#define ID_ADDRESS                      32787
#define ID_REPLY                        32788
#define ID_GPG_DEC                      32789
#define ID_GPG_ENC                      32790
#define ID_RETRIEVE                     32791
#define ID_SETTING                      32792
#define ID_GPG_EXP                      32794
#define ID_GPG_IMPORT                   32795
#define ID_GPG_IMPORT_                  32795
#define ID_REMOVE_FILE                  32797
#define ID_INFO                         32799
#define ID_TEXTVIEW_COPY                32800
#define ID_TEXTVIEW_RETR                32801
#define ID_TEXTVIEW_SELALL              32802
#define ID_EDITVIEW_CUT                 32803
#define ID_EDITVIEW_COPY                32804
#define ID_EDITVIEW_PASTE               32805
#define ID_EDITVIEW_SELALL              32806
#define ID_EDITVIEW_UNDO                32807
#define ID_TEXTVIEW_BROWSER             32808
#define ID_TEXTVIEW_EDITOR              32809
#define ID_SAVE_TO_DRAFT                32857
#define ID_REPLY_QUOTATION              32862
#define ID_REPLY_NO_QUOTATION           32863
#define ID_TRANSFER_RFC822              32864
#define ID_CHANGE_BK_COLOR              32865
#define ID_CHANGE_TXT_COLOR             32866
#define ID_HD_TXT_COLOR                 32867
#define ID_CHANGE_HD_TXT_COLOR          32868
#define ID_CHANGE_BK_COLOR_DRAFT        32869
#define ID_CHANGE_TXT_COLOR_DRAFT       32870
#define ID_EDITVIEW_PASTE_QUOTATION     32871
#define ID_GPG_DECODE                   32872
#define ID_GPG_KEY                      32873
#define ID_GPG                          32879
#define ID_FOLDERVIEW_ADD               32880
#define ID_DRAFT_GPG                    32881
#define ID_FOLDERVIEW_DEL               32882
#define ID_DRAFT_ADDRESS                32883
#define ID_FOLDERVIEW_RESTRUCT          32884
#define ID_FOLDERVIEW_RENAME            32885
#define ID_DRAFT_EXT_EDITOR             32886
#define ID_CHANGE_FONT                  32887
#define ID_SETTING_ACCOUNT              32888
#define ID_SETTING_GENERAL              32889
#define ID_DISPLAY_HEADER               32890
#define ID_DISPLAY_RAW_MAIL             32891
#define ID_SETTING_FILTER               32892
#define ID_SETTING_NEW_ACCOUNT          32893
#define ID_TRANSFER_QUOTATION           32894
#define ID_GPG_MAIN_KEY_MANAGEMENT      32895
#define ID_GPG_DRAFT_KEY_MANAGEMENT     32896
#define ID_FOLDERVIEW_CLEAR_TRASH       32897
#define ID_TRANSFER_ATTACH              32898
#define ID_SUMMARYVIEW_DEL              32899
#define ID_SUMMARYVIEW_REBUILD          32900
#define ID_SUMMARYVIEW_HEADER_INFO      32901
#define ID_SUMMARYVIEW_RAWMAIL_INFO     32902
#define ID_INDICATOR_TEXT               59143
#define ID_INDICATOR_PROGRESS           59144
#define ID_INDICATOR_FOLDER             59145

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        204
#define _APS_NEXT_COMMAND_VALUE         32901
#define _APS_NEXT_CONTROL_VALUE         1092
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> pochy-0.1.3-src.tar.gz: pochy-0.1.3-src/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by pochy.rc
//
#define ID_NEWACCOUNT                   3
#define ID_GENKEY                       3
#define ID_SAVE_USER                    4
#define ID_REMOVE_USER                  4
#define ID_DELKEY                       4
#define IDD_ABOUTBOX                    100
#define IDD_FORMVIEW                    101
#define IDR_MAINFRAME                   128
#define IDR_MOOTYPE                     129
#define IDR_DRAFTFRAME                  129
#define IDB_TREEVIEW                    132
#define IDI_ICON1                       133
#define IDI_ICON2                       134
#define IDI_ICON3                       135
#define IDR_MULTIPART                   136
#define IDR_MULTIPART_POPUP             136
#define IDI_ICON4                       137
#define IDD_DIALOG1                     138
#define IDD_PROGRESS                    138
#define IDD_DIALOG2                     139
#define IDD_DIALOG3                     140
#define IDD_RETRIEVE                    140
#define IDB_BITMAP2                     142
#define IDD_DIALOG4                     143
#define IDD_PASSWORD                    143
#define IDD_DIALOG5                     144
#define IDD_GPG_ENCODE_SELKEY           144
#define IDD_DIALOG6                     145
#define IDD_SETTING_ACCOUNT             145
#define IDD_DIALOG7                     148
#define IDD_DIALOG8                     149
#define IDR_EMPTY_HTML                  151
#define IDR_MULTIPART_DRAFT             152
#define IDR_MULTIPART_DRAFT_POPUP       152
#define IDD_DIALOG9                     153
#define IDD_DRAFT_CONFIRM               153
#define IDR_TEXTVIEW_POPUP              154
#define IDD_DIALOG10                    155
#define IDR_EDITVIEW_POPUP              156
#define IDR_TEST                        158
#define IDR_TOOLBAR1                    160
#define IDB_BITMAP3                     165
#define IDR_TOOLBAR2                    166
#define IDR_TOOLBAR3                    168
#define IDR_MAINFRAME_POPUP_REPLY       170
#define IDR_MAINFRAME_POPUP_TRANSFER    171
#define IDD_DIALOG11                    172
#define IDD_ADDR2_TAB_TO                173
#define IDD_ADDR2_TAB1                  173
#define IDD_ADDR2_TAB_PG1               173
#define IDC_ADDR2_LIST2                 173
#define IDR_MAINFRAME_POPUP_GPG         174
#define IDD_GPG_GENERAL                 175
#define IDR_TOOLBAR4                    178
#define IDR_DRAFTFRAME_POPUP_GPG        180
#define IDR_FOLDERVIEW_POPUP            181
#define IDD_ADDRESSVIEW                 182
#define IDD_FILTER                      183
#define IDD_ACCOUNTVIEW                 185
#define IDD_DRAFT_ADDRESSBOOK           190
#define IDD_MAIN_ADDRESSBOOK            191
#define IDD_SETTING_GENERAL             192
#define IDR_MAINFRAME_POPUP_SETTING     193
#define IDD_MAIN_ADDRESSBOOK_ADD        194
#define IDR_MAINFRAME_POPUP_INFO        195
#define IDD_DRAFT_ADDRESSBOOK_ADD       196
#define IDD_MAIN_ADDRESSBOOK_EDIT       197
#define IDD_SETTING_GENERAL_APPEARANCE  198
#define IDD_SETTING_GENERAL_OTHER       199
#define IDD_DIALOG12                    200
#define IDD_DRAFT_SEND_STATUS           201
#define IDR_SUMMARYVIEW_POPUP           203
#define IDB_DRAG                        204
#define IDC_EDIT1                       1000
#define IDC_EDIT2                       1001
#define IDC_PROGRESS1                   1002
#define IDC_EDIT3                       1002
#define IDC_BUTTON1                     1003
#define IDC_EDIT4                       1003
#define IDC_GPG_EXPORT                  1003
#define IDC_LIST1                       1004
#define IDC_EDIT5                       1004
#define IDC_BUTTON2                     1005
#define IDC_ADDR2_LIST1                 1005
#define IDC_FROM                        1005
#define IDC_EDIT6                       1006
#define IDC_BUTTON3                     1006
#define IDC_ADDR2_DEL2                  1006
#define IDC_FILTER_REPLACE              1006
#define IDC_SETTING_ADDRESS             1006
#define IDC_MAINFRAME_ADDRESSBOOK_DEL   1006
#define IDC_COMBO1                      1007
#define IDC_BUTTON4                     1007
#define IDC_PASS                        1007
#define IDC_BUTTON_TO                   1007
#define IDC_SETTING_GENERAL_DEFACCOUNT  1007
#define IDC_SETTING_DEF_ADDRESS         1007
#define IDC_EDIT7                       1008
#define IDC_LIST2                       1008
#define IDC_BUTTON5                     1008
#define IDC_FILTER_MOVE_TO              1008
#define IDC_SETTING_USERID              1008
#define IDC_DRAFT_ADDRESSBOOK_DST_LIST  1008
#define IDC_BUTTON_CC                   1008
#define IDC_BUTTON6                     1009
#define IDC_FILTER_FIELD                1009
#define IDC_SETTING_BOXNAME             1009
#define IDC_BUTTON_BCC                  1009
#define IDC_SETTING_SIG                 1011
#define IDC_SETTING_CHECK_DELMAIL       1014
#define IDC_COMBOBOXEX1                 1016
#define IDC_SETTING_CHECK_POP_BEFORE_SMTP 1017
#define IDC_DRAFT_ADDRESSBOOK_TAB       1019
#define IDC_SETTING_GENERAL_TAB         1019
#define IDC_ADDR2_ADD                   1020
#define IDC_GPG_DEL                     1028
#define IDC_GPG_KEY_TYPE                1029
#define IDC_GPG_DSA                     1030
#define IDC_GPG_ELG                     1031
#define IDC_GPG_KEY_LENGTH              1032
#define IDC_GPG_1024                    1033
#define IDC_GPG_2048                    1034
#define IDC_GPG_ADD                     1035
#define IDC_GPG_ADD_KEY                 1035
#define IDC_GPG_DATE2                   1037
#define IDC_GPG_REAL_NAME               1039
#define IDC_GPG_COMMENT                 1040
#define IDC_MAIL_ADDRESS                1041
#define IDC_GPG_DATE1                   1043
#define IDC_GPG_CREATE                  1044
#define IDC_GPG_LIST1                   1045
#define IDC_GPG_KEY                     1046
#define IDC_GPG_CLEAR1                  1047
#define IDC_GPG_CLEAR2                  1048
#define IDC_GPG_STATUS                  1049
#define IDC_GPG_OPEN_KEY                1050
#define IDC_TO                          1050
#define IDC_CC                          1051
#define IDC_BCC                         1052
#define IDC_SUBJECT                     1053
#define IDC_REPLY_TO                    1054
#define IDC_FILTER_PHRASE               1055
#define IDC_FILTER_CONDITION            1056
#define IDC_FILTER_ADD                  1057
#define IDC_FILTER_DEL                  1058
#define IDC_COMBO_ACCOUNT               1059
#define IDC_STATIC_FROM                 1060
#define IDC_STATIC_SUBJECT              1061
#define IDC_STATIC_REPLY_TO             1062
#define IDC_SETTING_PASS                1063
#define IDC_SETTING_POP_IP              1064
#define IDC_SETTING_SMTP_IP             1065
#define IDC_SETTING_POP_PORT            1066
#define IDC_SETTING_SMTP_PORT           1067
#define IDC_DRAFT_ADDRESSBOOK_ORG_LIST  1068
#define IDC_DRAFT_ADDRESSBOOK_ADD       1069
#define IDC_DRAFT_ADDRESSBOOK_DEL       1070
#define IDC_DRAFT_ADDRESSBOOK_EDIT      1071
#define IDC_MAINFRAME_ADDRESS_LIST      1071
#define IDC_MAINFRAME_ADDRESSBOOK_ADD   1072
#define IDC_DRAFT_ADDRESSBOOK_ADD2      1072
#define IDC_MAINFRAME_ADDRESSBOOK_EDIT  1073
#define IDC_DRAFT_ADDRESSBOOK_ADD_NAME  1074
#define IDC_MAIN_ADDRESSBOOK_ADD_NAME   1074
#define IDC_DRAFT_ADDRESSBOOK_ADD_ADDRESS 1075
#define IDC_MAIN_ADDRESSBOOK_ADD_ADDRESS 1075
#define IDC_DRAFT_ADDRESSBOOK_ADD_OTHERS 1076
#define IDC_MAIN_ADDRESSBOOK_ADD_OTHERS 1076
#define IDC_MAIN_ADDRESSBOOK_EDIT_NAME  1078
#define IDC_MAIN_ADDRESSBOOK_EDIT_ADDRESS 1079
#define IDC_MAIN_ADDRESSBOOK_EDIT_OTHER 1080
#define IDC_SETTING_GENERAL_FOLDERVIEW_BG_COLOR 1081
#define IDC_SETTING_GENERAL_SUMMARYVIEW_BG_COLOR 1082
#define IDC_SETTING_GENERAL_TEXTVIEW_BG_COLOR 1083
#define IDC_SETTING_GENERAL_AUTOFETCH_MINUTES 1083
#define IDC_SETTING_GENERAL_FOLDERVIEW_FONT_COLOR 1084
#define IDC_SETTING_GENERAL_EDITOR_REF  1084
#define IDC_SETTING_GENERAL_SUMMARYVIEW_FONT_COLOR 1085
#define IDC_SETTING_GENERAL_EDITOR_PATH 1085
#define IDC_SETTING_GENERAL_TEXTVIEW_FONT_COLOR 1086
#define IDC_DRAFT_SEND_PROGRESS         1086
#define IDC_SETTING_GENERAL_TEXTVIEW_FONT_TYPE 1087
#define IDC_DRAFT_SEND_STATUS           1087
#define IDC_SETTING_GENERAL_TEXTVIEW_HEADER_COLOR 1088
#define IDC_DRAFT_ADDRESSBOOK_CHECK_ADDRESS 1088
#define IDC_SETTING_GENERAL_EDITVIEW_BG_COLOR 1089
#define IDC_SETTING_CHECK_APOP          1089
#define IDC_SETTING_GENERAL_EDITVIEW_FONT_COLOR 1090
#define IDC_ABOUTBOX_VERSION            1090
#define IDC_SETTING_GENERAL_EDITVIEW_FONT_TYPE 1091
#define IDC_APPABOUT_COPY               1091
#define IDC_SETTING_DEF_ADDRESS_EDIT    1092
#define ID_DRAFT                        32771
#define ID_FETCH_MAIL                   32773
#define ID_SEND_MAIL                    32774
#define ID_TRANSFER                     32779
#define ID_ADD_FILE                     32780
#define ID_SAVETO_FILE                  32782
#define ID_MULTIPART_SAVE2FILE          32782
#define ID_MULTIPART_HEADER             32783
#define ID_ADDRESS                      32787
#define ID_REPLY                        32788
#define ID_GPG_DEC                      32789
#define ID_GPG_ENC                      32790
#define ID_RETRIEVE                     32791
#define ID_SETTING                      32792
#define ID_GPG_EXP                      32794
#define ID_GPG_IMPORT                   32795
#define ID_GPG_IMPORT_                  32795
#define ID_REMOVE_FILE                  32797
#define ID_INFO                         32799
#define ID_TEXTVIEW_COPY                32800
#define ID_TEXTVIEW_RETR                32801
#define ID_TEXTVIEW_SELALL              32802
#define ID_EDITVIEW_CUT                 32803
#define ID_EDITVIEW_COPY                32804
#define ID_EDITVIEW_PASTE               32805
#define ID_EDITVIEW_SELALL              32806
#define ID_EDITVIEW_UNDO                32807
#define ID_TEXTVIEW_BROWSER             32808
#define ID_TEXTVIEW_EDITOR              32809
#define ID_SAVE_TO_DRAFT                32857
#define ID_REPLY_QUOTATION              32862
#define ID_REPLY_NO_QUOTATION           32863
#define ID_TRANSFER_RFC822              32864
#define ID_CHANGE_BK_COLOR              32865
#define ID_CHANGE_TXT_COLOR             32866
#define ID_HD_TXT_COLOR                 32867
#define ID_CHANGE_HD_TXT_COLOR          32868
#define ID_CHANGE_BK_COLOR_DRAFT        32869
#define ID_CHANGE_TXT_COLOR_DRAFT       32870
#define ID_EDITVIEW_PASTE_QUOTATION     32871
#define ID_GPG_DECODE                   32872
#define ID_GPG_KEY                      32873
#define ID_GPG                          32879
#define ID_FOLDERVIEW_ADD               32880
#define ID_DRAFT_GPG                    32881
#define ID_FOLDERVIEW_DEL               32882
#define ID_DRAFT_ADDRESS                32883
#define ID_FOLDERVIEW_RESTRUCT          32884
#define ID_FOLDERVIEW_RENAME            32885
#define ID_DRAFT_EXT_EDITOR             32886
#define ID_CHANGE_FONT                  32887
#define ID_SETTING_ACCOUNT              32888
#define ID_SETTING_GENERAL              32889
#define ID_DISPLAY_HEADER               32890
#define ID_DISPLAY_RAW_MAIL             32891
#define ID_SETTING_FILTER               32892
#define ID_SETTING_NEW_ACCOUNT          32893
#define ID_TRANSFER_QUOTATION           32894
#define ID_GPG_MAIN_KEY_MANAGEMENT      32895
#define ID_GPG_DRAFT_KEY_MANAGEMENT     32896
#define ID_FOLDERVIEW_CLEAR_TRASH       32897
#define ID_TRANSFER_ATTACH              32898
#define ID_SUMMARYVIEW_DEL              32899
#define ID_SUMMARYVIEW_REBUILD          32900
#define ID_SUMMARYVIEW_HEADER_INFO      32901
#define ID_SUMMARYVIEW_RAWMAIL_INFO     32902
#define ID_INDICATOR_TEXT               59143
#define ID_INDICATOR_PROGRESS           59144
#define ID_INDICATOR_FOLDER             59145

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        205
#define _APS_NEXT_COMMAND_VALUE         32901
#define _APS_NEXT_CONTROL_VALUE         1093
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
